@@ -8,7 +8,7 @@ use File::Share ':all';
 use Moo;
 use namespace::clean;
 
-our $VERSION = 0.11;
+our $VERSION = 0.12;
 
 # Get XML.
 has xml => (
@@ -57,66 +57,88 @@ For more information about Bucharest Map, click L<here|https://en.wikipedia.org/
 
 =head2 C<new>
 
+ my $obj = Map::Tube::Bucharest->new;
+
 Constructor.
 
 Returns instance of object.
 
 =head2 C<get_all_routes> [EXPERIMENTAL]
 
+ my $routes_ar = $obj->get_all_routes($from, $to);
+
 Get all routes from station to station.
 
 Returns reference to array with L<Map::Tube::Route> objects.
 
 =head2 C<get_line_by_id>
 
+ my $line = $obj->get_line_by_id($line_id);
+
 Get line object defined by id.
 
 Returns L<Map::Tube::Line> object.
 
 =head2 C<get_line_by_name>
 
+ my $line = $obj->get_line_by_name($line_name);
+
 Get line object defined by name.
 
 Returns L<Map::Tube::Line> object.
 
 =head2 C<get_lines>
 
+ my $lines_ar = $obj->get_lines;
+
 Get lines in metro map.
 
 Returns reference to unsorted array with L<Map::Tube::Line> objects.
 
 =head2 C<get_node_by_id>
 
+ my $station = $obj->get_node_by_id($station_id);
+
 Get station node by id.
 
 Returns L<Map::Tube::Node> object.
 
 =head2 C<get_node_by_name>
 
+ my $station = $obj->get_node_by_name($station_name);
+
 Get station node by name.
 
 Returns L<Map::Tube::Node> object.
 
 =head2 C<get_shortest_route>
 
+ my $route = $obj->get_shortest_route($from, $to);
+
 Get shortest route between C<$from> and C<$to> node names. Node names in C<$from> and C<$to> are case insensitive.
 
 Returns Map::Tube::Route object.
 
 =head2 C<get_stations>
 
+ my $stations_ar = $obj->get_stations($line);
+
 Get list of stations for concrete metro line.
 
 Returns reference to array with L<Map::Tube::Node> objects.
 
 =head2 C<name>
 
+ my $metro_name = $obj->name;
+
 Get metro name.
 
 Returns string with metro name.
 
 =head2 C<xml>
 
+ my $xml_file = $obj->xml;
+
 Get XML specification of Bucharest metro.
 
 Returns string with XML.
@@ -193,7 +215,7 @@ Returns string with XML.
  system "ls -l Bucharest.png";
 
  # Output like:
- # -rw-r--r-- 1 skim skim 151426 Dec 24 12:03 Bucharest.png
+ # -rw-r--r-- 1 skim skim 158214 21. led 14.21 Bucharest.png
 
 =begin html
 
@@ -267,6 +289,8 @@ Returns string with XML.
  # 1 Mai
  # Jiului
  # Parc Bazilescu
+ # Laminorului
+ # Străulești
 
 =head1 DEPENDENCIES
 
@@ -305,7 +329,7 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2014-2023 Michal Josef Špaček
+© 2014-2025 Michal Josef Špaček
 
 Artistic License
 
@@ -313,6 +337,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.11
+0.12
 
 =cut
